@@ -10,6 +10,10 @@ MANUFACTURER_IEAST: Final[str] = "iEAST"
 MANUFACTURER_WIIM: Final[str] = "WiiM"
 MANUFACTURER_GGMM: Final[str] = "GGMM"
 MANUFACTURER_MEDION: Final[str] = "Medion"
+MANUFACTURER_AUGUST: Final[str] = "August"
+MANUFACTURER_MUZO: Final[str] = "Muzo"
+MANUFACTURER_AUDIOPRO: Final[str] = "Audio Pro"
+MANUFACTURER_TRIANGLE: Final[str] = "Triangle"
 MANUFACTURER_GENERIC: Final[str] = "Generic"
 MODELS_ARTSOUND_SMART_ZONE4: Final[str] = "Smart Zone 4 AMP"
 MODELS_ARTSOUND_SMART_HYDE: Final[str] = "Smart Hyde"
@@ -33,8 +37,21 @@ MODELS_WIIM_AMP: Final[str] = "WiiM Amp"
 MODELS_WIIM_MINI: Final[str] = "WiiM Mini"
 MODELS_WIIM_PRO: Final[str] = "WiiM Pro"
 MODELS_WIIM_PRO_PLUS: Final[str] = "WiiM Pro Plus"
+MODELS_WIIM_AMP_PRO: Final[str] = "WiiM Amp Pro"
+MODELS_WIIM_ULTRA: Final[str] = "WiiM Ultra"
+MODELS_WIIM_AMP_ULTRA: Final[str] = "WiiM Amp Ultra"
+MODELS_WIIM_CI_MOD_S: Final[str] = "WiiM CI MOD S"
+MODELS_WIIM_CI_MOD_A80: Final[str] = "WiiM CI MOD A80"
 MODELS_GGMM_GGMM_E2: Final[str] = "GGMM E2"
 MODELS_MEDION_MD_43970: Final[str] = "Life P66970 (MD 43970)"
+MODELS_WR320: Final[str] = "WR320"
+MODELS_WS350: Final[str] = "WS350"
+MODELS_MUZO_COBBLESTONE: Final[str] = "MUZO Cobblestone Wi-Fi Audio Receiver"
+MODELS_AUDIOPRO_C3: Final[str] = "C3"
+MODELS_AUDIOPRO_C10: Final[str] = "C10"
+MODELS_AUDIOPRO_A10: Final[str] = "A10"
+MODELS_TRIANGLE_AIO_3: Final[str] = "AIO 3"
+
 MODELS_GENERIC: Final[str] = "Generic"
 
 PROJECTID_LOOKUP: Final[dict[str, tuple[str, str]]] = {
@@ -70,18 +87,31 @@ PROJECTID_LOOKUP: Final[dict[str, tuple[str, str]]] = {
     "WiiM_Amp_4layer": (MANUFACTURER_WIIM, MODELS_WIIM_AMP),
     "WiiM_Pro_with_gc4a": (MANUFACTURER_WIIM, MODELS_WIIM_PRO),
     "WiiM_Pro_Plus": (MANUFACTURER_WIIM, MODELS_WIIM_PRO_PLUS),
+    "WiiM_AMP": (MANUFACTURER_WIIM, MODELS_WIIM_AMP),
+    "WiiM_Amp_Pro": (MANUFACTURER_WIIM, MODELS_WIIM_AMP_PRO),
     "Muzo_Mini": (MANUFACTURER_WIIM, MODELS_WIIM_MINI),
     "GGMM_E2A": (MANUFACTURER_GGMM, MODELS_GGMM_GGMM_E2),
     "A16": (MANUFACTURER_MEDION, MODELS_MEDION_MD_43970),
+    "Lanzi_4566": (MANUFACTURER_AUGUST, MODELS_WR320),
+    "WS350": (MANUFACTURER_AUGUST, MODELS_WS350),
+    "a31imuzobox": (MANUFACTURER_MUZO, MODELS_MUZO_COBBLESTONE),
+    "AudioPro_C3": (MANUFACTURER_AUDIOPRO, MODELS_AUDIOPRO_C3),
+    "AudioPro_C10": (MANUFACTURER_AUDIOPRO, MODELS_AUDIOPRO_C10),
+    "AudioPro_A10": (MANUFACTURER_AUDIOPRO, MODELS_AUDIOPRO_A10),
+    "U-AIO3v2": (MANUFACTURER_TRIANGLE, MODELS_TRIANGLE_AIO_3),
+    "WiiM_Ultra": (MANUFACTURER_WIIM, MODELS_WIIM_ULTRA),
+    "WiiM_Amp_Ultra": (MANUFACTURER_WIIM, MODELS_WIIM_AMP_ULTRA),
+    "WiiM_CI_MOD_S": (MANUFACTURER_WIIM, MODELS_WIIM_CI_MOD_S),
+    "WiiM_CI_MOD_A80": (MANUFACTURER_WIIM, MODELS_WIIM_CI_MOD_A80),
 }
 
 
 def get_info_from_project(project: str) -> tuple[str, str]:
     """Get manufacturer and model info based on given project."""
-    if project not in PROJECTID_LOOKUP:
-        LOGGER.warning(
-            "The project name '%s' is not found in the manufacturer list. Kindly open an issue at https://github.com/velleman/python-linkplay/issues with the project name %s and mention the manufacturer of this product and the product name.",
-            project,
-            project,
-        )
+    #    if project not in PROJECTID_LOOKUP:
+    #        LOGGER.warning(
+    #            "The project name '%s' is not found in the manufacturer list. Kindly open an issue at https://github.com/velleman/python-linkplay/issues with the project name %s and mention the manufacturer of this product and the product name.",
+    #            project,
+    #            project,
+    #        )
     return PROJECTID_LOOKUP.get(project, (MANUFACTURER_GENERIC, MODELS_GENERIC))
